pub(crate) struct HyperlinkInterface {
bus_name: OwnedUniqueName,
node: PlatformNode,
}Fields
bus_name: OwnedUniqueNamenode: PlatformNodeImplementations
Sourceimpl HyperlinkInterface
impl HyperlinkInterface
pub fn new(bus_name: OwnedUniqueName, node: PlatformNode) -> Self
fn map_error(&self) -> impl '_ + FnOnce(Error) -> Error
Sourceimpl HyperlinkInterface
impl HyperlinkInterface
Sourcepub async fn n_anchors_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn n_anchors_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
NAnchors property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn start_index_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn start_index_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
StartIndex property.
This method should be called if a property value changes outside its setter method.
Sourcepub async fn end_index_changed(
&self,
__zbus__signal_emitter: &SignalEmitter<'_>,
) -> Result<()>
pub async fn end_index_changed( &self, __zbus__signal_emitter: &SignalEmitter<'_>, ) -> Result<()>
Emit the “PropertiesChanged” signal with the new value for the
EndIndex property.
This method should be called if a property value changes outside its setter method.